/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2021 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.component.im.sms;

import org.openvpms.component.business.domain.im.act.Act;
import org.openvpms.component.business.service.archetype.rule.IArchetypeRuleService;
import org.openvpms.sms.message.OutboundMessage;
import org.openvpms.web.component.im.delete.ActDeletionHandler;
import org.openvpms.web.component.im.delete.Deletable;
import org.openvpms.web.component.im.edit.IMObjectEditorFactory;
import org.springframework.transaction.PlatformTransactionManager;

/**
 * Deletion handler for <em>act.SMSMessage</em>.
 *
 * @author Tim Anderson
 */
public class SMSDeletionHandler extends ActDeletionHandler<Act> {

    /**
     * Constructs an {@link SMSDeletionHandler}.
     *
     * @param object             the act to delete
     * @param factory            the editor factory
     * @param transactionManager the transaction manager
     * @param service            the archetype service
     */
    public SMSDeletionHandler(Act object, IMObjectEditorFactory factory, PlatformTransactionManager transactionManager,
                              IArchetypeRuleService service) {
        super(object, factory, transactionManager, service);
    }

    /**
     * Determines if the object can be deleted.
     *
     * @return {@link Deletable#yes()} if the object can be deleted, otherwise {@link Deletable#no}
     */
    @Override
    public Deletable getDeletable() {
        return getObject().getStatus().equals(OutboundMessage.Status.PENDING.toString()) ?
               Deletable.yes() : Deletable.no();
    }

}
